Struct playfair::Playfair

source ·
pub struct Playfair { /* private fields */ }
Playfair cipher structure, stores data needed during the encryption/decryption

Implementations

Generates a new Playfair cipher structure with the keyword and appropriate padding to ensure it can fit into the matrix.

Get a copy of the keyword of the Playfair structure

Allow updating the current keyword of the Playfair object. This may be useful if you are encrypting and decrypting amonst multiple parties at once, and have numerous different keywords / matricies to operate over.