pub struct Playfair { /* private fields */ }Expand description
Playfair cipher structure, stores data needed during the encryption/decryption
Implementations
sourceimpl Playfair
impl Playfair
sourcepub fn new(kw: &str) -> Self
pub fn new(kw: &str) -> Self
Generates a new Playfair cipher structure with the keyword and appropriate padding to ensure it can fit into the matrix.
sourcepub fn update_keyword(&mut self, kw: &str)
pub fn update_keyword(&mut self, kw: &str)
Allow updating the current keyword of the Playfair object. This may be useful if you are encrypting and decrypting amonst multiple parties at once, and have numerous different keywords / matricies to operate over.